#ifndef QWT_DIMAP_H
#define QWT_DIMAP_H

class QwtDiMap {

 private:

	// PRIVATE DATA
	double d_x1, d_x2;  // double interval boundaries
	int d_y1,d_y2;      // integer interval boundaries
        int d_c1,d_c2;      // integer clipping boundaries
        double d_cnv;       // conversion factor
	int d_log;	   // logarithmic scale?
   
        double d_offset;
	// PRIVATE MEMBERS
	void newFactor();	

 public:
	
	// PUBLIC DATA
	static const double LogMin;
	static const double LogMax;

	// PUBLIC MEMBERS
	QwtDiMap();
	QwtDiMap(int i1, int i2, double d1, double d2);
	~QwtDiMap();
	
	int transform(double x) const;
	double xTransform(double x) const;
	double invTransform(int i) const;
	int limTransform(double x) const;
   	double limInvTransform(int i) const;

        void setClipRange(int c1, int c2);
        void setIntRange(int i1, int i2);
        void setDblRange(double d1, double d2,int lg = 0);
   
        void setOffset(double offset);
        double offset(void){return d_offset;}
   
	bool contains(double x) const;
	bool contains(int x) const;
	
	double d1() const {return d_x1;}
	double d2() const {return d_x2;}
	int i1() const {return /*transform(d_x1+d_offset);*/(int)(d_y1+d_offset);}
	int i2() const {return /*transform(d_x2+d_offset);*/(int)(d_y2+d_offset);}
   	int c1() const {return (int)(d_c1+d_offset);}
	int c2() const {return (int)(d_c2+d_offset);}
	inline bool logarithmic() const {return d_log;}
	
};

#endif






